==> zio-aws-s3control_3-5.17.146.2-sources.jar: zio/aws/s3control/model/GetAccessPointPolicyResponse.scala <==
package zio.aws.s3control.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.s3control.model.primitives.Policy
import scala.jdk.CollectionConverters.*
final case class GetAccessPointPolicyResponse(policy: Option[Policy] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyResponse = {
    import GetAccessPointPolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyResponse
      .builder()
      .optionallyWith(
        policy.map(value => Policy.unwrap(value): java.lang.String)
      )(_.policy)
      .build()
  }
  def asReadOnly
      : zio.aws.s3control.model.GetAccessPointPolicyResponse.ReadOnly =
    zio.aws.s3control.model.GetAccessPointPolicyResponse.wrap(buildAwsValue())
}
object GetAccessPointPolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3control.model.GetAccessPointPolicyResponse =
      zio.aws.s3control.model
        .GetAccessPointPolicyResponse(policy.map(value => value))
    def policy: Option[Policy]
    def getPolicy: ZIO[Any, AwsError, Policy] =
      AwsError.unwrapOptionField("policy", policy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyResponse
  ) extends zio.aws.s3control.model.GetAccessPointPolicyResponse.ReadOnly {
    override val policy: Option[Policy] = scala
      .Option(impl.policy())
      .map(value => zio.aws.s3control.model.primitives.Policy(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyResponse
  ): zio.aws.s3control.model.GetAccessPointPolicyResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-s3control_3-6.20.83.2-sources.jar: zio/aws/s3control/model/GetAccessPointPolicyResponse.scala <==
package zio.aws.s3control.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.s3control.model.primitives.Policy
import scala.jdk.CollectionConverters.*
final case class GetAccessPointPolicyResponse(
    policy: Optional[Policy] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyResponse = {
    import GetAccessPointPolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyResponse
      .builder()
      .optionallyWith(
        policy.map(value => Policy.unwrap(value): java.lang.String)
      )(_.policy)
      .build()
  }
  def asReadOnly
      : zio.aws.s3control.model.GetAccessPointPolicyResponse.ReadOnly =
    zio.aws.s3control.model.GetAccessPointPolicyResponse.wrap(buildAwsValue())
}
object GetAccessPointPolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3control.model.GetAccessPointPolicyResponse =
      zio.aws.s3control.model
        .GetAccessPointPolicyResponse(policy.map(value => value))
    def policy: Optional[Policy]
    def getPolicy: ZIO[Any, AwsError, Policy] =
      AwsError.unwrapOptionField("policy", policy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyResponse
  ) extends zio.aws.s3control.model.GetAccessPointPolicyResponse.ReadOnly {
    override val policy: Optional[Policy] = zio.aws.core.internal
      .optionalFromNullable(impl.policy())
      .map(value => zio.aws.s3control.model.primitives.Policy(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyResponse
  ): zio.aws.s3control.model.GetAccessPointPolicyResponse.ReadOnly =
    new Wrapper(impl)
}
